@@ -46,6 +46,8 @@
 #include "gui/guiprofile.h"
 #include "gui/mdwslider.h"
 
+// Restore volume button feature is incomplete => disabling for KDE 4.10
+#undef RESTORE_VOLUME_BUTTON
 
 ViewDockAreaPopup::ViewDockAreaPopup(QWidget* parent, QString id, ViewBase::ViewFlags vflags, QString guiProfileId,
 	KMixWindow *dockW) :
@@ -145,7 +147,7 @@ void ViewDockAreaPopup::_setMixSet()
 	   if ( optionsLayout != 0 )
 	   {
 	     QLayoutItem *li2;
-	     while ( ( li2 = optionsLayout->takeAt(0) ) ) // strangely enough, it crashes here
+	     while ( ( li2 = optionsLayout->takeAt(0) ) )
 	 	    delete li2;
 	   }
 
@@ -200,20 +202,17 @@ Application: KMix (kmix), signal: Segmentation fault
 	 * BKO 299754: Looks like I need to explicitly delete layout(). I have no idea why
 	 *             "delete _layoutMDW" is not enough, as that is supposed to be the layout
 	 *             of this  ViewDockAreaPopup
+	 *             (Hint: it might have been 0 already)
 	 */
-	kDebug() << "2 layout()=" << layout() << ", _layoutMDW=" << _layoutMDW;
 	delete layout(); // BKO 299754
-	kDebug() << "3 layout()=" << layout() << ", _layoutMDW=" << _layoutMDW;
 //	delete _layoutMDW;
 	_layoutMDW = new QGridLayout(this);
-	kDebug() << "4 layout()=" << layout() << ", _layoutMDW=" << _layoutMDW;
 	_layoutMDW->setSpacing(KDialog::spacingHint());
 	_layoutMDW->setMargin(0);
 	//_layoutMDW->setSizeConstraint(QLayout::SetMinimumSize);
 	_layoutMDW->setSizeConstraint(QLayout::SetMaximumSize);
 	_layoutMDW->setObjectName(QLatin1String("KmixPopupLayout"));
     setLayout(_layoutMDW);
-	kDebug() << "5 layout()=" << layout() << ", _layoutMDW=" << _layoutMDW;
 
 	// Adding all mixers, as we potentially want to show all master controls. Due to hotplugging
 	// we have to redo the list on each _setMixSet() (instead of setting it once in the Constructor)
@@ -284,6 +283,11 @@ QWidget* ViewDockAreaPopup::add(shared_ptr<MixDevice> md)
   
     QString dummyMatchAll("*");
     QString matchAllPlaybackAndTheCswitch("pvolume,cvolume,pswitch,cswitch");
+    // Leak | relevant | pctl Each time a stream is added, a new ProfControl gets created.
+    //      It cannot be deleted in ~MixDeviceWidget, as ProfControl* ownership is not consistent.
+    //      here a new pctl is created (could be deleted), but in ViewSliders the ProcControl is taken from the
+    //      MixDevice, which in turn uses it from the GUIProfile.
+    //  Summarizing: ProfControl* is either owned by the GUIProfile or created new (ownership unclear).
     ProfControl *pctl = new ProfControl( dummyMatchAll, matchAllPlaybackAndTheCswitch);
     
     if ( !md->isApplicationStream() )
@@ -342,23 +346,27 @@ void ViewDockAreaPopup::constructionFinished()
    optionsLayout = new QHBoxLayout();
    optionsLayout->addWidget(mainWindowButton );
    optionsLayout->addWidget(configureViewButton);
+
+#ifdef RESTORE_VOLUME_BUTTON
    restoreVolumeButton1 = createRestoreVolumeButton(1);
    optionsLayout->addWidget( restoreVolumeButton1 ); // TODO enable only if user has saved a volume profile
+
 //    optionsLayout->addWidget( createRestoreVolumeButton(2) );
 //    optionsLayout->addWidget( createRestoreVolumeButton(3) );
 //    optionsLayout->addWidget( createRestoreVolumeButton(4) );
+#endif
    
       int sliderRow = _layoutMDW->rowCount();
       _layoutMDW->addLayout(optionsLayout, sliderRow, 0, 1, _layoutMDW->columnCount());
 
   	updateGuiOptions();
 
-    setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
+//    setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
 
     // TODO Resizing fails. Why?!?
 //    this->resize(_layoutMDW->minimumSize());
 //        this->resize(1,1);
-  	_layoutMDW->invalidate();
+//  	_layoutMDW->invalidate();
   	_layoutMDW->update();
       _layoutMDW->activate();
 //      setLayout(_layoutMDW);
